@@ -7,7 +7,16 @@ supporting document conversion, OCR, layout analysis, and table recognition.
 
 from .client import DatalabClient, AsyncDatalabClient
 from .exceptions import DatalabError, DatalabAPIError, DatalabTimeoutError
-from .models import ConversionResult, OCRResult, ConvertOptions, OCROptions
+from .models import (
+    ConversionResult,
+    OCRResult,
+    ConvertOptions,
+    OCROptions,
+    Workflow,
+    WorkflowStep,
+    WorkflowExecution,
+    InputConfig,
+)
 from .settings import settings
 
 __version__ = settings.VERSION
@@ -21,4 +30,8 @@ __all__ = [
     "OCRResult",
     "ConvertOptions",
     "OCROptions",
+    "Workflow",
+    "WorkflowStep",
+    "WorkflowExecution",
+    "InputConfig",
 ]
